@@ -388,18 +388,31 @@ def post_gitlab_feedback(ref_slot, test_slot, flavour, mr_slots_config):
         test_slot=test_slot.name,
         test_build=test_slot.build_id,
     )
-    message = ('Started [reference]({prefix}/{ref_id}/) '
-               'and [{mode} test]({prefix}/{test_id}/) '
-               'builds. Once done, check the [comparison]'
-               '({prefix}/compare?a={ref_id}&b={test_id})'
-               ' of build and test results.').format(
-                   prefix=prefix,
-                   flavour=flavour,
-                   ref_id=ref_id,
-                   test_id=test_id,
-                   mode=('integration'
-                         if mr_slots_config['merge'] else 'branch'),
-               )
+    if mr_slots_config['build_reference']:
+        message = ('Started [reference]({prefix}/{ref_id}/) '
+                   'and [{mode} test]({prefix}/{test_id}/) '
+                   'builds. Once done, check the [comparison]'
+                   '({prefix}/compare?a={ref_id}&b={test_id})'
+                   ' of build and test results.').format(
+                       prefix=prefix,
+                       flavour=flavour,
+                       ref_id=ref_id,
+                       test_id=test_id,
+                       mode=('integration'
+                             if mr_slots_config['merge'] else 'branch'),
+                   )
+    else:
+        message = (
+            'Started [{mode} test]({prefix}/{test_id}/) build.'
+            ' Once done, check the [results]({prefix}/{test_id}/)'
+            ' or the [comparison]({prefix}/compare?a={ref_id}&b={test_id})'
+            ' to a [reference]({prefix}/{ref_id}/) build.').format(
+                prefix=prefix,
+                flavour=flavour,
+                ref_id=ref_id,
+                test_id=test_id,
+                mode=('integration' if mr_slots_config['merge'] else 'branch'),
+            )
     logger.info('GitLab feedback: {!r}'.format(message))
     if os.environ.get('GITLAB_TOKEN'):
         trigger_source = mr_slots_config['trigger']
