@@ -547,6 +547,19 @@ class DashboardUpdate(object):
         results = defaultdict(list)
         for res in msg['results']:
             results[res['outcome']].append(res['id'])
+        # check that we are trying to update the result we created
+        from functools import reduce
+        current = self.dashboard.db[self.doc_name]
+        build_url = reduce(
+            lambda d, k: d.get(k) or {},
+            ['tests', self.platform, msg['project'], 'build_url'], current)
+        if build_url != self.build_url:
+            # some other build owns this entry, let's not mess with it
+            self.log.warning(
+                'attempt to update results from another test job (this: %s, other: %s)',
+                self.build_url, build_url)
+            return
+        # update the results
         data = {
             'tests': {
                 self.platform: {
