@@ -25,14 +25,14 @@ The code for the actual hook is located at [1].
 Example uses:
 - from MR lhcb/Rec!222
     /ci-test
-    /ci-test lhcb/LHCb@v50r6 gaudi/Gaudi@a729b15e6
     /ci-test --platforms=x86_64+avx2+fma-centos7-gcc8-opt
-    /ci-test --merge
+    /ci-test --branch
+    /ci-test --branch lhcb/LHCb@v50r6 gaudi/Gaudi@a729b15e6
 - from the command line
     lbn-gitlab-mr lhcb/Rec!222
-    lbn-gitlab-mr lhcb/Rec!222 lhcb/LHCb@v50r6 gaudi/Gaudi@a729b15e6
     lbn-gitlab-mr lhcb/Rec!222 --platforms=x86_64+avx2+fma-centos7-gcc8-opt
-    lbn-gitlab-mr lhcb/Rec!222 --merge
+    lbn-gitlab-mr lhcb/Rec!222 --branch
+    lbn-gitlab-mr lhcb/Rec!222 --branch lhcb/LHCb@v50r6 gaudi/Gaudi@a729b15e6
 
 [1]: https://gitlab.cern.ch/lhcb-core/lb-nightly-builds-frontend/blob/711225cddd663ba3622f3ea8f82d010ec5e287f7/lbnighties/ajax.py#L102-129
 
@@ -73,9 +73,20 @@ def get_hook_parser():
     parser.add_argument(
         '--platforms', help='Comma-separated list of platforms.')
     parser.add_argument(
+        '--build-reference',
+        action='store_true',
+        help='Also launch reference build for integration test mode')
+    mr_opts_group = parser.add_mutually_exclusive_group()
+    mr_opts_group.add_argument(
         '--merge',
         action='store_true',
+        default=True,
         help='Integration test mode (tip of target branch + MRs).')
+    mr_opts_group.add_argument(
+        '--branch',
+        action='store_false',
+        dest='merge',
+        help='Branch only test mode')
     # extra parameters passed to the main job, useful for testing, e.g.
     # --param scripts_version=branch-of-nightlies-jenkins-scripts
     # --param JENKINS_OVERRIDE_PIP_REQUIREMENTS=git+https://gitlab.
@@ -92,7 +103,9 @@ def get_hook_parser():
         raise TriggerError(message + '\n\n' + parser.format_help())
 
     parser.error = error
-    return parser, ['sources', 'platforms', 'merge', 'params']
+    return parser, [
+        'sources', 'platforms', 'merge', 'params', 'build_reference'
+    ]
 
 
 def parse_comment(comment):
@@ -300,9 +313,10 @@ def get_main_job_config(command_args=None):
 
         # set arguments from hook whenever they were not given on the
         # command line
+        # But always overwrite the merge option based on what's in the hook
         for p in hook_params:
             arg = getattr(hook_args, p)
-            if arg and not getattr(args, p):
+            if (arg and not getattr(args, p)) or p == 'merge':
                 setattr(args, p, arg)
     elif not args.sources:
         parser.error('specify at least one source or --hook-var')
@@ -322,6 +336,10 @@ def get_main_job_config(command_args=None):
             log_error(msg)
             raise TriggerError(msg)
 
+    # for branch only mode we always build a reference
+    if not args.merge:
+        args.build_reference = True
+
     # pass the hook arguments plus some other selected configuration
     config = {p: getattr(args, p) for p in hook_params}
     if args.hook_var:
