@@ -27,6 +27,9 @@ from datetime import datetime
 
 import gitlab
 
+from LbPlatformUtils import requires
+from LbPlatformUtils.architectures import get_supported_archs, ARCH_DEFS
+
 DAY_NAMES = ('Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun')
 
 
@@ -379,6 +382,13 @@ def recursive_update(dest, data):
     return dest
 
 
+class SlotAborted(Exception):
+    """
+    Exception raised when a slot was aborted.
+    """
+    pass
+
+
 class Dashboard(object):
     '''
     Wrapper for the CouchDB-based dashboard.
@@ -518,6 +528,17 @@ class Dashboard(object):
     def __getitem__(self, key):
         return self.db[key]
 
+    def assert_not_aborted(self, key):
+        """
+        Raise SlotAborted exception if the slot is flagged as aborted
+        """
+        try:
+            info = self.db[key].get("aborted")
+            if info:
+                raise SlotAborted(key, info)
+        except KeyError:
+            pass
+
 
 class TaskQueue(object):
     '''
@@ -1307,3 +1328,37 @@ class TemporaryDir(object):
         else:
             print "WARNING: not removing temporary directory", self.path
         return False
+
+
+def compatible_lcg_external_files(ext_file_name):
+    """
+    Given a filename like `/some/path/LCG_externals_<platform>.txt` return a list of
+    names where `<platform>` is replaced with a compatible architecture.
+    """
+    # we want to always try, at least, the passed name
+    paths = [ext_file_name]
+
+    # split the name in components
+    parts = re.match(r"^(.*/LCG_externals_)([^-]+)(-.*\.txt)$", ext_file_name)
+    if not parts:
+        # no need to continue if we do not understand the filename
+        return paths
+    head, arch, tail = parts.groups()
+
+    # this is a trick to promote "x86_64+avx2" to "x86_64_v3"
+    arch = requires(arch + "-...-").split("-", 1)[0]
+
+    if arch in ARCH_DEFS:
+        # if it's a known architecture we extend the list with the
+        # architectures we can use
+        archs = get_supported_archs(ARCH_DEFS[arch])
+        # list of externals files we could use
+        paths.extend("{}{}{}".format(head, arch, tail) for arch in archs)
+
+    # remove duplicates
+    unique = []
+    for path in paths:
+        if path not in unique:
+            unique.append(path)
+
+    return unique
