@@ -211,7 +211,10 @@ if [ -d /opt/dirac/lhcbpr/sw/jemalloc-3.6.0/lib ]; then
 fi
 
 # Get kerberos ticket
-kinit -k -t /afs/cern.ch/user/l/lhcbpr/private/lhcbpr.keytab lhcbpr@CERN.CH
+kinit -k -t $HOME/private/lhcbpr.keytab lhcbpr@CERN.CH
+
+# we need a grid proxy to upload result to Dirac
+export X509_USER_PROXY=$HOME/private/.shifterCred
 
 echo $LD_LIBRARY_PATH
 # Now running the test itself
@@ -251,11 +254,6 @@ data_dict['app_version_datetime'] = '{app_version_datetime}'
 dash.update(doc_name, data_dict)
 END`
 
-# Set environment for throughput tests
-if [[ '{handlers}' == *"Throughput"* ]] ; then
-    source /cvmfs/projects.cern.ch/intelsw/psxe/linux/19-all-setup.sh
-fi
-
 if [ -z "$LHCBPR_MOCK_OUTPUT_PATH" ]
 then
     {run_cmd} 2>&1 | tee run.log
